BannerInstructions class

Constructors

BannerInstructions({double? distanceAlongGeometry, Primary? primary, Primary? sub, Primary? secondary})
BannerInstructions.fromJson(Map<String, dynamic> map)
factory

Properties

distanceAlongGeometry double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
primary Primary?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Primary?
getter/setter pair
sub Primary?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited