CongestionLevel enum

A CongestionLevel indicates the level of traffic congestion along a road segment relative to the normal flow of traffic along that segment. You can color-code a route line according to the congestion level along each segment of the route.

Inheritance
Available extensions

Values

unknown → const CongestionLevel

There is not enough data to determine the level of congestion along the road segment.

low → const CongestionLevel

The road segment has little or no congestion. Traffic is flowing smoothly. Low congestion levels are conventionally highlighted in green or not highlighted at all.

moderate → const CongestionLevel

The road segment has moderate, stop-and-go congestion. Traffic is flowing but speed is impeded. Moderate congestion levels are conventionally highlighted in yellow.

heavy → const CongestionLevel

The road segment has heavy, bumper-to-bumper congestion. Traffic is barely moving. Heavy congestion levels are conventionally highlighted in orange.

severe → const CongestionLevel

The road segment has severe congestion. Traffic may be completely stopped. Severe congestion levels are conventionally highlighted in red.

Properties

description String

Available on CongestionLevel, provided by the CongestionLevelExtension extension

Get the string description of the CongestionLevel.
no setter
description String

Available on Enum, provided by the EnumExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CongestionLevel>
A constant List of the values in this enum, in order of their declaration.