MapRouteLayerProvider class

Constructors

MapRouteLayerProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initializeDurationSymbolLayer() SymbolLayerProperties
initializeRouteLayer(double routeScale, double alternativeRouteScale, Color routeDefaultColor, Color alternativeRouteDefaultColor, Color routeModerateColor, Color routeHeavyColor, Color routeSevereColor, Color alternativeRouteModerateColor, Color alternativeRouteHeavyColor, Color alternativeRouteSevereColor) LineLayerProperties
initializeRouteShieldLayer(double routeScale, double alternativeRouteScale, Color routeShieldColor, Color alternativeRouteShieldColor) LineLayerProperties
initializeWayPointLayer(String originMarkerName, String destinationMarkerName) SymbolLayerProperties
list(double base, double routeScale, double alternativeRouteScale) List<Object>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited