NavNextBillionMap class

Implemented types

Properties

assetManager IAssetManager
getter/setter pair
controller MapController
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onRerouteFailureCallback OnRouteSelectedCallback?
no setter
routeLayerProvider MapRouteLayerProvider
getter/setter pair
routeLayers Map<String, LayerProperties>
getter/setter pair
routeLineProperties RouteLineProperties
getter/setter pair
routeLines List<List<LatLng>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRouteSelectedListener(OnRouteSelectedCallback onRouteSelectedCallback) → void
Adds a listener for route selection. The clickedPoint represents the point clicked on the map. The onRouteSelectedCallback will be invoked when a route is selected.
override
clearRoute() Future<void>
Clears the currently displayed route from the map.
override
clearSources() Future<void>
drawIndependentRoutes(List<DirectionsRoute> routes, {int primaryRouteIndex = 0}) Future<void>
Draws the route on the map based on the provided routes. it clears the previous route before drawing the new one. and then draws the route line, waypoints, and route duration symbol. This method is used when there are multiple origin and destination routes. The primaryRouteIndex parameter is used to determine the primary route to be drawn. Default is 0.
override
drawRoute(List<DirectionsRoute> routes, {int primaryRouteIndex = 0}) Future<void>
Draws the route on the map based on the provided routes. it clears the previous route before drawing the new one. and then draws the route line, waypoints, and route duration symbol. The primaryRouteIndex parameter is used to determine the primary route to be drawn. Default is 0.
override
initGeoJsonSource() Future<void>
override
initRouteLayers() Future<void>
add route shield layer, route layer, waypoint layer and route duration layer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRouteSelectedListener() → void
Removes the listener for route selection.
override
retrievePrimaryRouteIndex() int
Returns the primary route index.
retrieveRoutes() List<DirectionsRoute>
Returns the list of routes.
safeAddGeoJsonSource(String sourceId, Map<String, dynamic> geoJson) Future
safeRemoveLayer(String layerId) Future
safeRemoveSource(String sourceId) Future
safeSetGeoJsonSource(String sourceId, Map<String, dynamic> geoJson) Future
toggleAlternativeVisibilityWith(bool alternativeVisible) Future<void>
Toggles the visibility of alternative routes on the map. The alternativeVisible parameter determines whether alternative routes should be visible or not.
override
toggleDurationSymbolVisibilityWith(bool durationSymbolVisible) → void
Toggles the visibility of the duration symbol on the map. The durationSymbolVisible parameter determines whether the duration symbol should be visible or not.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(NextbillionMapController controller, {RouteLineProperties routeLineProperties = const RouteLineProperties()}) Future<NavNextBillionMap>
createWithAssetManager(MapController mapController, IAssetManager assetManager, {RouteLineProperties routeLineProperties = const RouteLineProperties()}) Future<NavNextBillionMap>