DirectionsRoute class
Constructors
-
DirectionsRoute({num? distance, num? duration, String? geometry, required List<
Leg> legs, String? routeIndex, RouteRequestParams? routeOptions, num? weight, String? countryCode, String? weightName, String? voiceLanguage, List<CongestionLevel> ? congestion}) -
DirectionsRoute.fromJson(Map<
String, dynamic> map) -
factory
-
DirectionsRoute.fromJsonWithOption(Map<
String, dynamic> map, RouteRequestParams option) -
factory
Properties
-
congestion
↔ List<
CongestionLevel> ? -
getter/setter pair
- countryCode ↔ String?
-
getter/setter pair
- distance ↔ num?
-
getter/setter pair
- duration ↔ num?
-
getter/setter pair
- geometry ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
legs
↔ List<
Leg> -
getter/setter pair
- routeIndex ↔ String?
-
getter/setter pair
- routeOptions ↔ RouteRequestParams?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voiceLanguage ↔ String?
-
getter/setter pair
- weight ↔ num?
-
getter/setter pair
- weightName ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited