NBNavigationPlatform class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureRouteDurationSymbol(
DirectionsRoute route, bool isPrimaryRoute) → Future< Uint8List?> -
captureRouteWaypoints(
int waypointIndex) → Future< Uint8List?> -
fetchRoute(
RouteRequestParams routeRequestParams) → Future< DirectionsRouteResponse> -
findSelectedRouteIndex(
LatLng clickPoint, List< List< coordinates) → Future<LatLng> >int?> -
getFormattedDuration(
num durationSeconds) → Future< String?> -
getRoutingBaseUri(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setRoutingBaseUri(
String baseUri) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → NBNavigationPlatform
-
no setter