Adds a listener for route selection.
The clickedPoint represents the point clicked on the map.
The onRouteSelectedCallback will be invoked when a route is selected.
Draws the route on the map based on the provided routes.
it clears the previous route before drawing the new one.
and then draws the route line, waypoints, and route duration symbol.
This method is used when there are multiple origin and destination routes.
The primaryRouteIndex parameter is used to determine the primary route to be drawn. Default is 0.
Draws the route on the map based on the provided routes.
it clears the previous route before drawing the new one.
and then draws the route line, waypoints, and route duration symbol.
The primaryRouteIndex parameter is used to determine the primary route to be drawn. Default is 0.
Toggles the visibility of alternative routes on the map.
The alternativeVisible parameter determines whether alternative routes should be visible or not.
Toggles the visibility of the duration symbol on the map.
The durationSymbolVisible parameter determines whether the duration symbol should be visible or not.