NavigationProgress class
Constructors
-
factory
Properties
- currentLegIndex ↔ int?
-
getter/setter pair
- currentLegProgress ↔ CurrentLegProgress?
-
getter/setter pair
- currentStepIndex ↔ int?
-
getter/setter pair
- currentStepPointIndex ↔ int?
-
getter/setter pair
- distanceRemaining ↔ num?
-
getter/setter pair
- distanceTraveled ↔ num?
-
getter/setter pair
- durationRemaining ↔ num?
-
getter/setter pair
- fractionTraveled ↔ num?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFinalLeg ↔ bool?
-
getter/setter pair
- location ↔ LatLng?
-
getter/setter pair
- remainingWaypoints ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited