SnapshotOptions class
Set of options for taking map snapshot
Constructors
- SnapshotOptions({required double width, required double height, LatLng? centerCoordinate, LatLngBounds? bounds, double? zoomLevel, double? pitch, double? heading, String? styleUri, String? styleJson, bool? withLogo, bool? writeToDisk, PlatformWrapper? platformWrapper})
-
The
widthandheightarguments must not be null
Properties
- bounds → LatLngBounds?
-
The coordinate rectangle that encompasses the bounds to capture. This is applied after the camera position
final
- centerCoordinate → LatLng?
-
If you want to take snapshot with camera position option
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → double?
-
If you want to take snapshot with camera position option
final
- height → double
-
Dimensions of the snapshot
The height of the image
final
- pitch → double?
-
If you want to take snapshot with camera position option
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleJson → String?
-
StyleJson of the map style to snapshot
final
- styleUri → String?
-
URL of the map style to snapshot. The URL may be a full HTTP or HTTPS URL, a NBMap style URL
final
- width → double
-
Dimensions of the snapshot
The width of the image
final
- withLogo → bool
-
Android Only: The flag indicating to show the Nbmap logo
final
- writeToDisk → bool
-
True: Save snapshot in cache and return path
False: Return base64 value
final
- zoomLevel → double?
-
If you want to take snapshot with camera position option
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited